@@ -12,10 +12,6 @@ We `test <https://travis-ci.org/gittip/postgres.py>`_ against Python 2.6, 2.7,
 3.2, and 3.3. We don't yet have a testing matrix for different versions of
 :py:mod:`psycopg2` or PostgreSQL.
 
-Importing :py:mod:`postgres` under Python 2 will cause the registration of
-typecasters with :py:mod:`psycopg2` to ensure that you get unicode instead of
-bytestrings for text data, according to `this advice`_.
-
 :py:mod:`postgres` is in the `public domain`_.
 
 
@@ -39,9 +35,9 @@ Use :py:meth:`~postgres.Postgres.one` to fetch exactly one result:
     {'bar': 'baz'}
 
 
-Use :py:meth:`~postgres.Postgres.rows` to fetch all results:
+Use :py:meth:`~postgres.Postgres.all` to fetch all results:
 
-    >>> db.rows("SELECT * FROM foo ORDER BY bar")
+    >>> db.all("SELECT * FROM foo ORDER BY bar")
     [{'bar': 'baz'}, {'bar': 'buz'}]
 
 
@@ -68,7 +64,7 @@ Context Managers
 
 Eighty percent of your database usage should be covered by the simple
 :py:meth:`~postgres.Postgres.run`, :py:meth:`~postgres.Postgres.one`,
-:py:meth:`~postgres.Postgres.rows` API introduced above. For the other 20%,
+:py:meth:`~postgres.Postgres.all` API introduced above. For the other 20%,
 :py:mod:`postgres` provides context managers for working at increasingly lower
 levels of abstraction. The lowest level of abstraction in :py:mod:`postgres` is
 a :py:mod:`psycopg2` `connection pool
@@ -104,10 +100,10 @@ of your code block, when the context manager commits the transaction for you::
 
     >>> with db.get_transaction() as txn:
     ...     txn.execute("INSERT INTO foo VALUES ('blam')")
-    ...     db.rows("SELECT * FROM foo ORDER BY bar")
+    ...     db.all("SELECT * FROM foo ORDER BY bar")
     ...
     [{'bar': 'baz'}, {'bar': 'buz'}]
-    >>> db.rows("SELECT * FROM foo ORDER BY bar")
+    >>> db.all("SELECT * FROM foo ORDER BY bar")
     [{'bar': 'baz'}, {'bar': 'blam'}, {'bar': 'buz'}]
 
 The :py:func:`~postgres.Postgres.get_transaction` manager gives you a cursor
@@ -166,7 +162,7 @@ from psycopg2.extras import RealDictCursor
 from psycopg2.pool import ThreadedConnectionPool as ConnectionPool
 
 
-__version__ = '1.0.0'
+__version__ = '1.0.1'
 
 
 # A Helper
@@ -219,8 +215,16 @@ class Postgres(object):
 
     This is the main object that :py:mod:`postgres` provides, and you should
     have one instance per process for each PostgreSQL database your process
-    wants to talk to using this library. When instantiated, this object creates
-    a `thread-safe connection pool
+    wants to talk to using this library.
+
+    >>> import postgres
+    >>> db = postgres.Postgres("postgres://jrandom@localhost/test")
+
+    (Note that importing :py:mod:`postgres` under Python 2 will cause the
+    registration of typecasters with :py:mod:`psycopg2` to ensure that you get
+    unicode instead of bytestrings for text data, according to `this advice`_.)
+
+    When instantiated, this object creates a `thread-safe connection pool
     <http://initd.org/psycopg/docs/pool.html#psycopg2.pool.ThreadedConnectionPool>`_,
     which opens :py:attr:`minconn` connections immediately, and up to
     :py:attr:`maxconn` according to demand. The fundamental value of a
@@ -233,21 +237,21 @@ class Postgres(object):
     :py:class:`NamedTupleCursor`.
 
     The names in our simple API, :py:meth:`~postgres.Postgres.run`,
-    :py:meth:`~postgres.Postgres.one`, and :py:meth:`~postgres.Postgres.rows`,
+    :py:meth:`~postgres.Postgres.one`, and :py:meth:`~postgres.Postgres.all`,
     were chosen to be short and memorable, and to not conflict with the DB-API
     2.0 :py:meth:`execute`, :py:meth:`fetchone`, and :py:meth:`fetchall`
     methods, which have slightly different semantics (under DB-API 2.0 you call
     :py:meth:`execute` on a cursor and then call one of the :py:meth:`fetch*`
     methods on the same cursor to retrieve rows; with our simple API there is
-    no second :py:meth:`fetch` step). The context managers on this class are
-    named starting with :py:meth:`get_` to set them apart from the simple-case
-    API.  Note that when working inside a block under one of the context
-    managers, you're using DB-API 2.0 (:py:meth:`execute` + :py:meth:`fetch*`),
-    not our simple API (:py:meth:`~postgres.Postgres.run` /
-    :py:meth:`~postgres.Postgres.one` / :py:meth:`~postgres.Postgres.rows`).
+    no second :py:meth:`fetch` step). See `this ticket`_ for more of the
+    rationale behind these names. The context managers on this class are named
+    starting with :py:meth:`get_` to set them apart from the simple-case API.
+    Note that when working inside a block under one of the context managers,
+    you're using DB-API 2.0 (:py:meth:`execute` + :py:meth:`fetch*`), not our
+    simple API (:py:meth:`~postgres.Postgres.run` /
+    :py:meth:`~postgres.Postgres.one` / :py:meth:`~postgres.Postgres.all`).
 
-    >>> import postgres
-    >>> db = postgres.Postgres("postgres://jrandom@localhost/test")
+    .. _this ticket: https://github.com/gittip/postgres.py/issues/16
 
     """
 
@@ -292,7 +296,7 @@ class Postgres(object):
         :type parameters: dict or tuple
         :param strict: whether to raise when there isn't exactly one result
         :type strict: :py:class:`bool`
-        :returns: :py:class:`dict` or :py:const:`None`
+        :returns: a single row or :py:const:`None`
         :raises: :py:exc:`~postgres.TooFew` or :py:exc:`~postgres.TooMany`
 
         By default, :py:attr:`strict` ends up evaluating to :py:class:`True`,
@@ -303,7 +307,7 @@ class Postgres(object):
         :py:attr:`strict_one` to the :py:class:`~postgres.Postgres`
         constructor. If you use both, the :py:attr:`strict` argument here wins.
 
-        >>> row = db.one("SELECT * FROM foo WHERE bar='baz'"):
+        >>> row = db.one("SELECT * FROM foo WHERE bar='baz'")
         >>> print(row["bar"])
         baz
 
@@ -328,15 +332,15 @@ class Postgres(object):
 
             return cursor.fetchone()
 
-    def rows(self, sql, parameters=None):
+    def all(self, sql, parameters=None):
         """Execute a query and return all resulting rows.
 
         :param unicode sql: the SQL statement to execute
         :param parameters: the bind parameters for the SQL statement
         :type parameters: dict or tuple
-        :returns: :py:class:`list` of :py:class:`dict`
+        :returns: :py:class:`list` of rows
 
-        >>> for row in db.rows("SELECT bar FROM foo"):
+        >>> for row in db.all("SELECT bar FROM foo"):
         ...     print(row["bar"])
         ...
         baz
@@ -347,13 +351,21 @@ class Postgres(object):
             cursor.execute(sql, parameters)
             return cursor.fetchall()
 
+    def rows(self, *a, **kw):
+
+        # This is for backwards compatibility, see #16. It is stubbed instead
+        # of aliased to avoid showing up in our docs via sphinx autodoc.
+
+        return self.all(*a, **kw)
+
+
     def get_cursor(self, *a, **kw):
         """Return a :py:class:`~postgres.CursorContextManager` that uses our
         connection pool.
 
-        This is what :py:meth:`~postgres.Postgres.execute`,
-        :py:meth:`~postgres.Postgres.fetchone`, and
-        :py:meth:`~postgres.Postgres.fetchall` use under the hood. You might
+        This is what :py:meth:`~postgres.Postgres.run`,
+        :py:meth:`~postgres.Postgres.one`, and
+        :py:meth:`~postgres.Postgres.all` use under the hood. You might
         use it if you want to access `cursor attributes
         <http://initd.org/psycopg/docs/cursor.html>`_, for example.
 
